@@ -3,18 +3,25 @@
 import os
 
 from akerbp.mlops.core import logger
-from akerbp.mlops.cdf.helpers import count_file_versions, download_folder
-from akerbp.mlops.cdf.helpers import upload_folder, query_file_versions
+import akerbp.mlops.cdf.helpers as cdf
+
+
 
 logging=logger.get_logger(name='MLOps')
 
 ENV = os.environ['ENV']
 
 
+def setup(cdf_api_keys):
+    cdf.api_keys = cdf_api_keys
+    cdf.set_up_cdf_client()
+
+
 def upload_new_model_version(model_name, env, folder, metadata):
     """
     Upload a new model version. Files in a folder are archived and stored 
-    with external id `model_name/env/version`, where version is automatically increased. 
+    with external id `model_name/env/version`, where version is automatically
+    increased. 
 
     Input:
         -model_name: name of the model 
@@ -28,7 +35,7 @@ def upload_new_model_version(model_name, env, folder, metadata):
     """
 
     filter = f"{model_name}/{env}/"
-    version = count_file_versions(filter, directory_prefix='/mlops') + 1
+    version = cdf.count_file_versions(filter, directory_prefix='/mlops') + 1
     if "version" in metadata:
         logging.error(
             "Metadata should not contain a 'version' key. "
@@ -37,7 +44,7 @@ def upload_new_model_version(model_name, env, folder, metadata):
     metadata["version"] = version
     external_id = f"{model_name}/{env}/{version}"
 
-    folder_info = upload_folder(
+    folder_info = cdf.upload_folder(
         external_id, 
         folder, 
         metadata,
@@ -60,7 +67,7 @@ def find_model_version(model_name, env, metadata):
         'version' key
     """
     
-    file_list = query_file_versions(
+    file_list = cdf.query_file_versions(
         directory_prefix='/mlops', 
         external_id_prefix=f"{model_name}/{env}",
         metadata=metadata
@@ -89,10 +96,10 @@ def download_model_version(model_name, env, folder, metadata={}):
         -folder: path to folder where the content will be uploaded
         -metadata: query to the metadata (dictionary)
     """
-    external_id = find_model_version(model_name, env, metadata)
+    external_id = cdf.find_model_version(model_name, env, metadata)
     if not os.path.isdir(folder):
         os.makedirs(folder)
-    download_folder(external_id, folder)
+    cdf.download_folder(external_id, folder)
     logging.info(f"Downloaded model with {external_id=} to {folder}")
     return external_id
 
@@ -119,6 +126,6 @@ def set_up_model_artifact(artifact_folder, model_name):
             message = f"Existing artifacts won't be used ({ENV=})"
             logging.warning(message)
     logging.info("Download serialized model")
-    model_id = download_model_version(model_name, ENV, artifact_folder)
+    model_id = cdf.download_model_version(model_name, ENV, artifact_folder)
 
     return model_id
\ No newline at end of file
